#[repr(u8)]pub enum Cfg {
CNT_CHAR = 0,
CNT_IDLE = 1,
CNT_BUSY_IDLE = 2,
CNT_CHAR_IDLE = 3,
}Variants
CNT_CHAR = 0
Becomes 1 after timeout characters are received
CNT_IDLE = 1
Becomes 1 when idle for timeout bit clocks
CNT_BUSY_IDLE = 2
Becomes 1 when idle for timeout bit clocks following the next character
CNT_CHAR_IDLE = 3
Becomes 1 when idle for at least timeout bit clocks, but a new character is detected before the extended idle timeout is reached
Implementations